Index — cookies_utilities 0.0.1 documentation

# Index

A | C | G | H | P | S | T

## A

append() (cookies_utilities.HtmlHelper method) | append_heading() (cookies_utilities.HtmlHelper method) append_markdown() (cookies_utilities.HtmlHelper method)

## C

convert_time_to_feature() (in module cookies_utilities) | copy_datetime() (in module cookies_utilities)

## G

get_dates() (in module cookies_utilities)

## H

has_diff_local_and_remote() (in module cookies_utilities) | HtmlHelper (class in cookies_utilities)

## P

press() (cookies_utilities.Stopwatch method)

## S

show() (cookies_utilities.Stopwatch method) | Stopwatch (class in cookies_utilities)

## T

to_html() (cookies_utilities.HtmlHelper method)